.. pyfakefs documentation master file, created by
   sphinx-quickstart on Mon Oct 31 20:05:53 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the pyfakefs documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

   intro
   usage
   autopatch
   modules
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

